Add experimental notes around p2p

Tento commit je obsažen v:
Ben Sander
2016-04-18 23:52:42 -05:00
rodič 9329fb8c92
revize 21d733b2e7
+14 -3
Zobrazit soubor
@@ -910,6 +910,8 @@ hipError_t hipMemGetInfo (size_t * free, size_t * total) ;
* @defgroup PeerToPeer Device Memory Access * @defgroup PeerToPeer Device Memory Access
* @{ * @{
* *
* @warning PeerToPeer support is experimental.
*
*/ */
/** /**
@@ -926,6 +928,7 @@ hipError_t hipMemGetInfo (size_t * free, size_t * total) ;
* *
* @returns #hipSuccess, * @returns #hipSuccess,
* @returns #hipErrorInvalidDevice if deviceId or peerDeviceId are not valid devices * @returns #hipErrorInvalidDevice if deviceId or peerDeviceId are not valid devices
* @warning PeerToPeer support is experimental.
*/ */
hipError_t hipDeviceCanAccessPeer (int* canAccessPeer, int deviceId, int peerDeviceId); hipError_t hipDeviceCanAccessPeer (int* canAccessPeer, int deviceId, int peerDeviceId);
@@ -943,6 +946,7 @@ hipError_t hipDeviceCanAccessPeer (int* canAccessPeer, int deviceId, int peerDev
* *
* Returns #hipSuccess, #hipErrorInvalidDevice, #hipErrorInvalidValue, * Returns #hipSuccess, #hipErrorInvalidDevice, #hipErrorInvalidValue,
* @returns #hipErrorPeerAccessAlreadyEnabled if peer access is already enabled for this device. * @returns #hipErrorPeerAccessAlreadyEnabled if peer access is already enabled for this device.
* @warning PeerToPeer support is experimental.
*/ */
hipError_t hipDeviceEnablePeerAccess (int peerDeviceId, unsigned int flags); hipError_t hipDeviceEnablePeerAccess (int peerDeviceId, unsigned int flags);
@@ -954,11 +958,13 @@ hipError_t hipDeviceEnablePeerAccess (int peerDeviceId, unsigned int flags);
* *
* @param [in] peerDeviceId * @param [in] peerDeviceId
* *
* Returns #hipSuccess, #hipErrorPeerAccessNotEnabled * @returns #hipSuccess, #hipErrorPeerAccessNotEnabled
* @warning PeerToPeer support is experimental.
*/ */
hipError_t hipDeviceDisablePeerAccess (int peerDeviceId); hipError_t hipDeviceDisablePeerAccess (int peerDeviceId);
#ifdef PEER_NON_UNIFIED
/** /**
* @brief Copies memory from one device to memory on another device. * @brief Copies memory from one device to memory on another device.
* *
@@ -968,7 +974,8 @@ hipError_t hipDeviceDisablePeerAccess (int peerDeviceId);
* @param [in] srcDeviceId - Source device * @param [in] srcDeviceId - Source device
* @param [in] sizeBytes - Size of memory copy in bytes * @param [in] sizeBytes - Size of memory copy in bytes
* *
* Returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDevice * @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDevice
* @warning PeerToPeer support is experimental.
*/ */
hipError_t hipMemcpyPeer (void* dst, int dstDeviceId, const void* src, int srcDeviceId, size_t sizeBytes); hipError_t hipMemcpyPeer (void* dst, int dstDeviceId, const void* src, int srcDeviceId, size_t sizeBytes);
@@ -982,19 +989,23 @@ hipError_t hipMemcpyPeer (void* dst, int dstDeviceId, const void* src, int srcDe
* @param [in] sizeBytes - Size of memory copy in bytes * @param [in] sizeBytes - Size of memory copy in bytes
* @param [in] stream - Stream identifier * @param [in] stream - Stream identifier
* *
* Returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDevice * @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDevice
*/ */
#if __cplusplus #if __cplusplus
hipError_t hipMemcpyPeerAsync ( void* dst, int dstDeviceId, const void* src, int srcDevice, size_t sizeBytes, hipStream_t stream=0 ); hipError_t hipMemcpyPeerAsync ( void* dst, int dstDeviceId, const void* src, int srcDevice, size_t sizeBytes, hipStream_t stream=0 );
#else #else
hipError_t hipMemcpyPeerAsync(void* dst, int dstDevice, const void* src, int srcDevice, size_t sizeBytes, hipStream_t stream); hipError_t hipMemcpyPeerAsync(void* dst, int dstDevice, const void* src, int srcDevice, size_t sizeBytes, hipStream_t stream);
#endif #endif
#endif
// doxygen end PeerToPeer // doxygen end PeerToPeer
/** /**
* @} * @}
*/ */
/** /**
*------------------------------------------------------------------------------------------------- *-------------------------------------------------------------------------------------------------
*------------------------------------------------------------------------------------------------- *-------------------------------------------------------------------------------------------------